==> gtk+-2.90.7.tar.bz2: gtk+-2.90.7/gdk/x11/gdkeventsource.h <==
/* GDK - The GIMP Drawing Kit
 * Copyright (C) 2009 Carlos Garnacho <carlosg@gnome.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef __GDK_EVENT_SOURCE_H__
#define __GDK_EVENT_SOURCE_H__

#include "gdkeventtranslator.h"
#include "gdkprivate-x11.h"

G_BEGIN_DECLS

typedef struct _GdkEventSource GdkEventSource;

G_GNUC_INTERNAL
GSource * gdk_event_source_new            (GdkDisplay *display);

G_GNUC_INTERNAL
void      gdk_event_source_add_translator (GdkEventSource     *source,
                                           GdkEventTranslator *translator);

G_GNUC_INTERNAL
void      gdk_event_source_select_events  (GdkEventSource *source,
                                           Window          window,
                                           GdkEventMask    event_mask,
                                           unsigned int    extra_x_mask);


G_END_DECLS

#endif /* __GDK_EVENT_SOURCE_H__ */

==> gtk+-3.1.2.tar.bz2: gtk+-3.1.2/gdk/x11/gdkeventsource.h <==
/* GDK - The GIMP Drawing Kit
 * Copyright (C) 2009 Carlos Garnacho <carlosg@gnome.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef __GDK_EVENT_SOURCE_H__
#define __GDK_EVENT_SOURCE_H__

#include "gdkeventtranslator.h"

G_BEGIN_DECLS

typedef struct _GdkEventSource GdkEventSource;

G_GNUC_INTERNAL
GSource * gdk_x11_event_source_new            (GdkDisplay *display);

G_GNUC_INTERNAL
void      gdk_x11_event_source_add_translator (GdkEventSource  *source,
                                               GdkEventTranslator *translator);

G_GNUC_INTERNAL
void      gdk_x11_event_source_select_events  (GdkEventSource *source,
                                               Window          window,
                                               GdkEventMask    event_mask,
                                               unsigned int    extra_x_mask);


G_END_DECLS

#endif /* __GDK_EVENT_SOURCE_H__ */
